==> react-native-neurosdk2-1.0.24.tgz: package/android/src/main/java/com/neurosdk2/BrainBitBlackImpl.java <==
package com.neurosdk2;

import static com.neurosdk2.Utils.ConvertFPGData;
import static com.neurosdk2.Utils.ConvertMEMSData;
import static com.neurosdk2.Utils.DATA_ID;
import static com.neurosdk2.Utils.GUID_ID;
import static com.neurosdk2.Utils.sendEvent;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.neurosdk2.neuro.BrainBitBlack;
import com.neurosdk2.neuro.Sensor;
import com.neurosdk2.neuro.types.FPGData;
import com.neurosdk2.neuro.types.IrAmplitude;
import com.neurosdk2.neuro.types.MEMSData;
import com.neurosdk2.neuro.types.RedAmplitude;

public class BrainBitBlackImpl extends BrainBitImpl{
  public BrainBitBlackImpl(Sensor sensor, String guid, ReactApplicationContext context) {
    super(sensor, guid, context);
    addCallbacks();
  }

  @Override
  protected void addCallbacks() {
    super.addCallbacks();
    ((BrainBitBlack)sensor).fpgDataReceived = (data)->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (FPGData fpgData : data) {
        WritableMap map = Arguments.createMap();
        ConvertFPGData(fpgData, map);
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      sendEvent(reactContext, Constants.NEUROSMART_FPGDATA_CHANGED_EVENT_NAME.raw(), result);
    };
    ((BrainBitBlack)sensor).memsDataReceived = (data)->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (MEMSData memsData : data) {
        WritableMap map = Arguments.createMap();
        ConvertMEMSData(memsData, map);
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      sendEvent(reactContext,Constants.MEMSDATA_CHANGED_EVENT_NAME.raw(), result);
    };
    ((BrainBitBlack)sensor).sensorAmpModeChanged = (data)->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      result.putInt(DATA_ID, data.index());
      sendEvent(reactContext,Constants.AMPMODE_CHANGED_EVENT_NAME.raw(), result);
    };
  }

  @Override
  protected void removeCallbacks() {
    super.removeCallbacks();
    ((BrainBitBlack)sensor).fpgDataReceived = null;
    ((BrainBitBlack)sensor).memsDataReceived = null;
    ((BrainBitBlack)sensor).sensorAmpModeChanged = null;
  }

  @Override
  protected String getSensorName() {
    return "BrainBitBlack";
  }

  @Override
  public int getSamplingFrequencyMEMS() throws Exception {
    return ((BrainBitBlack)sensor).getSamplingFrequencyMEMS().index();
  }

  @Override
  public int getSamplingFrequencyFPG() throws Exception {
    return ((BrainBitBlack)sensor).getSamplingFrequencyFPG().index();
  }

  @Override
  public int getSamplingFrequencyResist() throws Exception {
    return ((BrainBitBlack)sensor).getSamplingFrequencyResist().index();
  }

  @Override
  public int getIrAmplitude() throws Exception {
    return ((BrainBitBlack)sensor).getIrAmplitude().index();
  }

  @Override
  public void setIrAmplitude(int amp) throws Exception {
    ((BrainBitBlack)sensor).setIrAmplitude(IrAmplitude.indexOf(amp));
  }

  @Override
  public int getRedAmplitude() throws Exception {
    return ((BrainBitBlack)sensor).getRedAmplitude().index();
  }

  @Override
  public void setRedAmplitude(int amp) throws Exception {
    ((BrainBitBlack)sensor).setRedAmplitude(RedAmplitude.indexOf(amp));
  }

  @Override
  public int getAmpMode() throws Exception {
    return ((BrainBitBlack)sensor).getAmpMode().index();
  }

  @Override
  public void pingNeuroSmart(double marker) throws Exception {
    ((BrainBitBlack)sensor).pingNeuroSmart((byte)marker);
  }

}

==> react-native-neurosdk2-1.0.27.tgz: package/android/src/main/java/com/neurosdk2/BrainBitBlackImpl.java <==
package com.neurosdk2;

import static com.neurosdk2.Utils.ConvertFPGData;
import static com.neurosdk2.Utils.ConvertMEMSData;
import static com.neurosdk2.Utils.DATA_ID;
import static com.neurosdk2.Utils.GUID_ID;
import static com.neurosdk2.Utils.sendEvent;

import com.facebook.react.bridge.Arguments;
import com.facebook.react.bridge.ReactApplicationContext;
import com.facebook.react.bridge.WritableArray;
import com.facebook.react.bridge.WritableMap;
import com.neurosdk2.neuro.BrainBitBlack;
import com.neurosdk2.neuro.Sensor;
import com.neurosdk2.neuro.types.FPGData;
import com.neurosdk2.neuro.types.IrAmplitude;
import com.neurosdk2.neuro.types.MEMSData;
import com.neurosdk2.neuro.types.RedAmplitude;
import com.facebook.react.bridge.CxxCallbackImpl;

public class BrainBitBlackImpl extends BrainBitImpl{
  public BrainBitBlackImpl(Sensor sensor, String guid, ReactApplicationContext context, CxxCallbackImpl sensorCallback) {
    super(sensor, guid, context, sensorCallback);
    addCallbacks();
  }

  @Override
  protected void addCallbacks() {
    super.addCallbacks();
    ((BrainBitBlack)sensor).fpgDataReceived = (data)->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (FPGData fpgData : data) {
        WritableMap map = Arguments.createMap();
        ConvertFPGData(fpgData, map);
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      if(cxxCallback == null){
        sendEvent(reactContext, Constants.NEUROSMART_FPGDATA_CHANGED_EVENT_NAME.raw(), result);
      }
      else 
      {
        cxxCallback.invoke(Constants.NEUROSMART_FPGDATA_CHANGED_EVENT_NAME.raw(), result);
      }
    };
    ((BrainBitBlack)sensor).memsDataReceived = (data)->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      WritableArray array = Arguments.createArray();
      for (MEMSData memsData : data) {
        WritableMap map = Arguments.createMap();
        ConvertMEMSData(memsData, map);
        array.pushMap(map);
      }
      result.putArray(DATA_ID, array);
      if(cxxCallback == null){
        sendEvent(reactContext,Constants.MEMSDATA_CHANGED_EVENT_NAME.raw(), result);
      }
      else 
      {
        cxxCallback.invoke(Constants.MEMSDATA_CHANGED_EVENT_NAME.raw(), result);
      }
    };
    ((BrainBitBlack)sensor).sensorAmpModeChanged = (data)->{
      WritableMap result = Arguments.createMap();
      result.putString(GUID_ID, guid);
      result.putInt(DATA_ID, data.index());
      if(cxxCallback == null){
        sendEvent(reactContext,Constants.AMPMODE_CHANGED_EVENT_NAME.raw(), result);
      }
      else 
      {
        cxxCallback.invoke(Constants.AMPMODE_CHANGED_EVENT_NAME.raw(), result);
      }
    };
  }

  @Override
  protected void removeCallbacks() {
    super.removeCallbacks();
    ((BrainBitBlack)sensor).fpgDataReceived = null;
    ((BrainBitBlack)sensor).memsDataReceived = null;
    ((BrainBitBlack)sensor).sensorAmpModeChanged = null;
  }

  @Override
  protected String getSensorName() {
    return "BrainBitBlack";
  }

  @Override
  public int getSamplingFrequencyMEMS() throws Exception {
    return ((BrainBitBlack)sensor).getSamplingFrequencyMEMS().index();
  }

  @Override
  public int getSamplingFrequencyFPG() throws Exception {
    return ((BrainBitBlack)sensor).getSamplingFrequencyFPG().index();
  }

  @Override
  public int getSamplingFrequencyResist() throws Exception {
    return ((BrainBitBlack)sensor).getSamplingFrequencyResist().index();
  }

  @Override
  public int getIrAmplitude() throws Exception {
    return ((BrainBitBlack)sensor).getIrAmplitude().index();
  }

  @Override
  public void setIrAmplitude(int amp) throws Exception {
    ((BrainBitBlack)sensor).setIrAmplitude(IrAmplitude.indexOf(amp));
  }

  @Override
  public int getRedAmplitude() throws Exception {
    return ((BrainBitBlack)sensor).getRedAmplitude().index();
  }

  @Override
  public void setRedAmplitude(int amp) throws Exception {
    ((BrainBitBlack)sensor).setRedAmplitude(RedAmplitude.indexOf(amp));
  }

  @Override
  public int getAmpMode() throws Exception {
    return ((BrainBitBlack)sensor).getAmpMode().index();
  }

  @Override
  public void pingNeuroSmart(double marker) throws Exception {
    ((BrainBitBlack)sensor).pingNeuroSmart((byte)marker);
  }

}
